import React from 'react';
import { View, ScrollView, StyleSheet } from 'react-native';
import { Cell } from './cell';
import type { StickyTableProps } from '../types';

/** StickyTable component - Table with sticky first column */
export const StickyTable: React.FC<StickyTableProps> = ({
  data,
  stickyColumnWidth,
  columnWidths = [],
  style,
  cellStyle,
  textStyle,
  headerStyle,
  headerTextStyle,
  borderStyle = { borderWidth: 1, borderColor: '#000' },
}) => {
  if (!data || data.length === 0) return null;

  // calc content width
  const contentWidth = columnWidths.reduce((sum, width) => sum + width, 0);

  return (
    <View style={[styles.container, style]}>
      {/* sticky Column */}
      <View style={[styles.stickyColumn, { width: stickyColumnWidth }]}>
        {data.map((row, rowIndex) => {
          const isHeader = rowIndex === 0;
          return (
            <View
              key={`sticky-${rowIndex}`}
              style={[
                cellStyle,
                isHeader && headerStyle,
                borderStyle && {
                  borderTopWidth: borderStyle.borderWidth,
                  borderLeftWidth: borderStyle.borderWidth,
                  borderBottomWidth: borderStyle.borderWidth,
                  borderRightWidth: borderStyle.borderWidth,
                  borderColor: borderStyle.borderColor,
                },
              ]}
            >
              <Cell
                data={row[0]}
                width={stickyColumnWidth}
                textStyle={[textStyle, isHeader && headerTextStyle]}
                borderStyle={{ borderWidth: 0 }} // no borders for inner cell
              />
            </View>
          );
        })}
      </View>

      {/* scrollable Content */}
      <ScrollView
        horizontal={true}
        style={styles.scrollView}
        showsHorizontalScrollIndicator={true}
      >
        <View style={{ width: contentWidth || undefined }}>
          {data.map((row, rowIndex) => {
            const isHeader = rowIndex === 0;
            // skip first column as it's already in the sticky part
            const rowData = row.slice(1);

            return (
              <View key={`row-${rowIndex}`} style={styles.row}>
                {rowData.map((cellData, cellIndex) => {
                  const colWidth = columnWidths[cellIndex];

                  return (
                    <View
                      key={`cell-${rowIndex}-${cellIndex}`}
                      style={[
                        cellStyle,
                        isHeader && headerStyle,
                        { width: colWidth },
                        borderStyle && {
                          borderTopWidth: borderStyle.borderWidth,
                          borderLeftWidth: borderStyle.borderWidth,
                          borderBottomWidth: borderStyle.borderWidth,
                          borderRightWidth: borderStyle.borderWidth,
                          borderColor: borderStyle.borderColor,
                        },
                      ]}
                    >
                      <Cell
                        data={cellData}
                        width={colWidth}
                        textStyle={[textStyle, isHeader && headerTextStyle]}
                        borderStyle={{ borderWidth: 0 }} // no borders for inner cell
                      />
                    </View>
                  );
                })}
              </View>
            );
          })}
        </View>
      </ScrollView>
    </View>
  );
};

const styles = StyleSheet.create({
  container: {
    flexDirection: 'row',
  },
  stickyColumn: {
    zIndex: 1,
    elevation: 3,
  },
  scrollView: {
    flex: 1,
  },
  row: {
    flexDirection: 'row',
  },
});
